﻿Copyright Fluke Calibration. All Rights Reserved.           MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek MSO/DPO5000 Remote Interface Connection
DATE:                  2012-07-17 12:02:15
AUTHOR:                Fluke
REVISION:              $Revision: 24326 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       133
=============================================================================
#
#  Procedure Author:
#        DAC
#
#  Models Covered:
#        DPO5034, DPO5054, DPO5104, DPO5204
#        MSO5034, MSO5054, MSO5104, MSO5204
#
#  Compatibility:
#        MET/CAL 7.3.38 or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  This procedure is intended for use with MET/CAL® calibration software;
#  the terms and conditions set forth in your MET/CAL license apply to this
#  procedure.
#
#  Due to Fluke's policy of continuously updating our products, this procedure
#  may contain minor differences in methods used and/or specifications to
#  those found in the manual or other documentation. While every effort has
#  been made to ensure that this procedure is accurate, Fluke cannot be held
#  responsible for the consequences of error or omissions found within this
#  procedure.
#
#  The copyright in this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Initialize interface variables not specified in the calling procedure.
  1.001  IF           NOT(ISVAR("@VisaUSB"))
  1.002  MATH         @VisaUSB = 0
  1.003  ENDIF

  1.004  IF           NOT(ISVAR("@VisaLAN"))
  1.005  MATH         @VisaLAN = 0
  1.006  ENDIF

# Make sure at least one support interface was specified.
  1.007  IF           NOT(@VisaUSB || @VisaLAN)
  1.008  DISP         Either @VisaUSB or @VisaLAN interface must be specified!
  1.009  MATH         @Abort = 1
  1.010  ENDIF

  1.011  MATH         USB = 0; LAN = 0

# If only one interface is supported by the DUT, choose it.
  1.012  IF           @VisaUSB && NOT(@VisaLAN)
  1.013  MATH         USB = 1

  1.014  ELSEIF       @VisaLAN && NOT(@VisaUSB)
  1.015  MATH         LAN = 1

# Otherwise allow operator to select the DUT interface to use.
  1.016  ELSE
  1.017  MATH         @Id = LBNEW("DUT REMOTE CONTROL INTERFACE")
  1.018  MEM2         =Select DUT interface to be used for calibration.
  1.019  MATH         LBTEXT(@Id, MEM2)
  1.020  MATH         LBCONF(@Id, "+SelReq")
  1.021  MATH         LBBUTTON(@Id, "OK")
  1.022  MATH         LBBUTTON(@Id, "Exit")

  1.023  IF           @VisaUSB
  1.024  MATH         LBADDV(@Id, "USB", "USB")
  1.025  ENDIF

  1.026  IF           @VisaLAN
  1.027  MATH         LBADDV(@Id, "LAN (Ethernet)", "LAN")
  1.028  ENDIF

# Return now if operator selected "Exit".
  1.029  IF           LBSHOW(@Id) == 2
  1.030  MATH         @Abort = 1
  1.031  END
  1.032  ENDIF

  1.033  ENDIF

# Display an appropriate message based on the DUT interface selected.
  1.034  IF           USB
  1.035  DISP         Using a USB Type A (Host) to USB Type B (Device) cable,
  1.035  DISP         connect an available PC USB port to the DUT (USB) DEVICE
  1.035  DISP         connector (on rear).
  1.035  DISP
  1.035  DISP         Ensure the Windows® operating system recognizes the
  1.035  DISP         "plug-and-play" device prior to proceeding.

  1.036  DISP         Configure the DUT for USB operation in accordance
  1.036  DISP         with instructions in the Tektronix DPO5000 Series
  1.036  DISP         Oscilloscopes User Manual.
  1.036  DISP
  1.036  DISP         Optionally, NI® Measurement & Automation Explorer (MAX)
  1.036  DISP         may be used to verify the USB connection, following the
  1.036  DISP         operating system's recognition of the device.

  1.037  ELSEIF       LAN
  1.038  DISP         Using an appropriate cable, connect the LAN (Ethernet,
  1.038  DISP         TCP/IP) to the DUT LAN Non-Auto-MDIX connector (rear).

  1.039  DISP         Configure the DUT for LAN operation in accordance
  1.039  DISP         with instructions in the Tektronix MSO/DPO5000 Series
  1.039  DISP         Oscilloscopes User Manual.

  1.040  DISP         NI® Measurement & Automation Explorer (MAX) MUST be
  1.040  DISP         used to establish a VISA resource name for the DUT,
  1.040  DISP         prior to proceeding.
  1.040  DISP
  1.040  DISP         Optionally, NI MAX may also be used to subsequently
  1.040  DISP         verify the DUT connection.
  1.041  ENDIF

  1.042  MATH         @Abort = 0
  1.043  END
